@@ -221,6 +221,7 @@ function create_k8s_api_service {
     local lb_name
     local use_octavia
     local project_id
+    local fixed_ips
 
     project_id=$(get_or_create_project \
         "$KURYR_NEUTRON_DEFAULT_PROJECT" default)
@@ -230,7 +231,8 @@ function create_k8s_api_service {
                              subnet show "$KURYR_NEUTRON_DEFAULT_SERVICE_SUBNET" \
                              -c cidr -f value)
 
-    kubelet_iface_ip=$(openstack port show kubelet-"${HOSTNAME}" -c fixed_ips -f value | cut -d \' -f 2)
+    fixed_ips=$(openstack port show kubelet-"${HOSTNAME}" -c fixed_ips -f value)
+    kubelet_iface_ip=$(python -c "print ${fixed_ips}[0]['ip_address']")
 
     k8s_api_clusterip=$(_cidr_range "$service_cidr" | cut -f1)
 
@@ -661,7 +663,8 @@ function run_k8s_controller_manager {
                 --root-ca-file=/srv/kubernetes/ca.crt
                 --min-resync-period=3m
                 --v=$(get_k8s_log_level)
-                --logtostderr=true)
+                --logtostderr=true
+                --leader-elect=false)
 
     run_container kubernetes-controller-manager "${command[@]}"
 }
@@ -681,7 +684,8 @@ function run_k8s_scheduler {
               /hyperkube scheduler
                 --master=$KURYR_K8S_API_URL
                 --v=$(get_k8s_log_level)
-                --logtostderr=true)
+                --logtostderr=true
+                --leader-elect=false)
 
     run_container kubernetes-scheduler "${command[@]}"
 }
@@ -766,7 +770,7 @@ function run_k8s_kubelet {
         --root-dir=${KURYR_HYPERKUBE_DATA_DIR}/kubelet"
 
     if [[ ${CONTAINER_ENGINE} == 'docker' ]]; then
-        command+=" --cgroup-driver $(docker info|awk '/Cgroup/ {print $NF}')"
+        command+=" --cgroup-driver $(docker info -f '{{.CgroupDriver}}')"
     elif [[ ${CONTAINER_ENGINE} == 'crio' ]]; then
         local crio_conf
         crio_conf=/etc/crio/crio.conf
@@ -871,7 +875,7 @@ spec:
       hostNetwork: true
       containers:
       - name: coredns
-        image: coredns/coredns:1.4.0
+        image: quay.io/kuryr/coredns:1.4.0
         imagePullPolicy: Always
         args: [ "-conf", "/etc/coredns/Corefile" ]
         volumeMounts:
