@@ -243,6 +243,8 @@ def patch_kuryrnetworkpolicy_crd(crd, i_rules, e_rules, pod_selector,
                               'egressSgRules': e_rules,
                               'podSelector': pod_selector,
                               'networkpolicy_spec': np_spec})
+    except k_exc.K8sResourceNotFound:
+        LOG.debug('KuryrNetPolicy CRD not found %s', crd_name)
     except k_exc.K8sClientException:
         LOG.exception('Error updating kuryrnetpolicy CRD %s', crd_name)
         raise
@@ -285,9 +287,10 @@ def create_security_group_rule_body(
 @MEMOIZE
 def get_pod_ip(pod):
     try:
-        vif = pod['annotations'][constants.K8S_ANNOTATION_VIF]
+        pod_metadata = pod['metadata']['annotations']
+        vif = pod_metadata[constants.K8S_ANNOTATION_VIF]
     except KeyError:
-        raise k_exc.ResourceNotReady(pod['metadata']['name'])
+        return None
     vif = jsonutils.loads(vif)
     vif = vif['versioned_object.data']['default_vif']
     network = (vif['versioned_object.data']['network']
@@ -444,6 +447,8 @@ def service_matches_affected_pods(service, pod_selectors):
             and False otherwise.
     """
     svc_selector = service['spec'].get('selector')
+    if not svc_selector:
+        return False
     for selector in pod_selectors:
         if match_selector(selector, svc_selector):
             return True
