@@ -59,7 +59,14 @@ class Dispatcher(h_base.EventHandler):
             key = key_fn(event)
             handlers.update(key_group.get(key, ()))
 
-        LOG.debug("%s handler(s) available", len(handlers))
+        obj = event.get('object', {})
+        obj_meta = obj.get('metadata', {})
+
+        LOG.debug("%d handler(s) available for event %s %s:%s/%s (uid: %s)",
+                  len(handlers), event.get('type'), obj.get('kind'),
+                  obj_meta.get('namespace'), obj_meta.get('name'),
+                  obj_meta.get('uid'))
+
         for handler in handlers:
             handler(event)
 
